import React, { useState, useEffect } from 'react'
import {
  Box,
  Button,
  Paper,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
  Typography,
  TablePagination,
  TextField,
  MenuItem,
  FormControl,
  InputLabel,
  Select,
  Skeleton,
} from '@mui/material'
import { useNavigate } from 'react-router-dom'

import { isAutheticated } from 'src/auth'
import Axios from '../../../axios'

const CancelledOrder = () => {
  const [orders, setOrders] = useState([])
  const [loading, setLoading] = useState(true)
  const [page, setPage] = useState(0)
  const [rowsPerPage, setRowsPerPage] = useState(5)
  const [totalOrders, setTotalOrders] = useState(0)
  const [searchField, setSearchField] = useState('uniqueId') // Default search field
  const [searchText, setSearchText] = useState('') // Default search text is empty
  const navigate = useNavigate()
  const token = isAutheticated()

  // Fetch orders based on page, limit, and search criteria
  const fetchOrders = async (page, limit, searchField, searchText) => {
    setLoading(true)
    try {
      const response = await Axios.get('/api/pd-get-cancelled-orders', {
        headers: {
          Authorization: `Bearer ${token}`,
        },
        params: {
          page: page + 1, // Pages are 1-indexed in backend
          limit,
          searchField: searchText ? searchField : undefined, // Only pass searchField if there's a searchText
          searchText: searchText || undefined, // Only pass searchText if it's not empty
        },
      })
      if (response?.status === 200) {
        setOrders(response?.data?.plcaedOrders)
        setTotalOrders(response?.data?.totalOrders)
      } else {
        setOrders([])
        setTotalOrders(0)
      }
    } catch (error) {
      console.error('Error fetching orders:', error)
    } finally {
      setLoading(false)
    }
  }

  // Fetch all orders initially and when page/rowsPerPage changes
  useEffect(() => {
    fetchOrders(page, rowsPerPage, searchField, searchText)
  }, [page, rowsPerPage])

  // Trigger search when search text or search field changes
  const handleSearchChange = (event) => {
    setSearchText(event.target.value)
  }

  useEffect(() => {
    if (searchText.trim()) {
      // Trigger search only when there is search text
      fetchOrders(0, rowsPerPage, searchField, searchText)
    } else {
      // If searchText is cleared, fetch all orders again
      fetchOrders(page, rowsPerPage, searchField, '')
    }
  }, [searchText, searchField])

  const handleSearchFieldChange = (event) => {
    setSearchField(event.target.value)
  }

  const handleChangePage = (event, newPage) => {
    setPage(newPage)
  }

  const handleChangeRowsPerPage = (event) => {
    setRowsPerPage(parseInt(event.target.value, 10))
    setPage(0)
  }

  return (
    <Box>
      <Typography variant="h4" mb={2} textAlign="center">
        New Order Placed List
      </Typography>
      <Box display="flex" mb={2} alignItems="center">
        <FormControl variant="outlined" sx={{ minWidth: 150, mr: 2 }}>
          <InputLabel id="search-field-label">Search By</InputLabel>
          <Select
            labelId="search-field-label"
            id="search-field"
            value={searchField}
            onChange={handleSearchFieldChange}
            label="Search By"
          >
            <MenuItem value="uniqueId">Order ID</MenuItem>
            <MenuItem value="status">Status</MenuItem>
          </Select>
        </FormControl>
        <TextField
          label={`Search by ${searchField}`}
          variant="outlined"
          value={searchText}
          onChange={handleSearchChange}
          fullWidth
        />
      </Box>
      <TableContainer component={Paper}>
        <Table>
          <TableHead>
            <TableRow>
              <TableCell>Order ID</TableCell>
              <TableCell>Order Date</TableCell>
              <TableCell>Items</TableCell>
              <TableCell>Order Value</TableCell>
              <TableCell>Status</TableCell>
              <TableCell>Action</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {loading ? (
              Array.from(new Array(rowsPerPage)).map((_, index) => (
                <TableRow key={index}>
                  <TableCell colSpan={6}>
                    <Skeleton height={40} />
                  </TableCell>
                </TableRow>
              ))
            ) : orders?.length > 0 ? (
              orders.map((order) => (
                <TableRow key={order._id}>
                  <TableCell>{order.uniqueId}</TableCell>
                  <TableCell>
                    {new Date(order.createdAt).toDateString()}
                    <span>, {formatAMPM(order.createdAt)}</span>
                  </TableCell>
                  <TableCell>{order.orderItem.length}</TableCell>
                  <TableCell>{order.grandTotal.toFixed(2)}</TableCell>
                  <TableCell>{order.status}</TableCell>
                  <TableCell>
                    <Button
                      variant="contained"
                      color="primary"
                      onClick={() => navigate(`/${order.status}/${order._id}`)}
                    >
                      View
                    </Button>
                  </TableCell>
                </TableRow>
              ))
            ) : (
              <TableRow>
                <TableCell colSpan={6} align="center">
                  <Typography variant="body1">Data not found</Typography>
                </TableCell>
              </TableRow>
            )}
          </TableBody>
        </Table>
        <TablePagination
          rowsPerPageOptions={[5, 10, 25]}
          component="div"
          count={totalOrders}
          rowsPerPage={rowsPerPage}
          page={page}
          onPageChange={handleChangePage}
          onRowsPerPageChange={handleChangeRowsPerPage}
        />
      </TableContainer>
    </Box>
  )
}

// Helper function to format time as AM/PM
const formatAMPM = (date) => {
  var hours = new Date(date).getHours()
  var minutes = new Date(date).getMinutes()
  var ampm = hours >= 12 ? 'PM' : 'AM'
  hours = hours % 12
  hours = hours ? hours : 12
  minutes = minutes < 10 ? '0' + minutes : minutes
  var strTime = hours + ':' + minutes + ' ' + ampm
  return strTime
}

export default CancelledOrder
